FittedBayesianRidge

Struct FittedBayesianRidge 

pub struct FittedBayesianRidge<F> { /* private fields */ }
Fitted Bayesian Ridge Regression model.

Stores the posterior mean coefficients, intercept, estimated noise precision (alpha), weight precision (lambda), and the diagonal of the posterior covariance matrix (sigma).

Implementations

Source

impl<F: Float> FittedBayesianRidge<F>

pub fn alpha(&self) -> F

Returns the estimated noise precision (alpha = 1/sigma²_noise).

pub fn lambda(&self) -> F

Returns the estimated weight precision (lambda = 1/sigma²_weights).

pub fn sigma(&self) -> &Array1<F>

Returns the diagonal of the posterior covariance matrix.