pub struct FittedLinearRegression<F> { /* private fields */ }Expand description
Fitted ordinary least squares linear regression model.
Stores the learned coefficients and intercept. Implements Predict
to generate predictions and HasCoefficients for introspection.
Implementations
Sourceimpl<F: Float> FittedLinearRegression<F>
impl<F: Float> FittedLinearRegression<F>
Sourcepub fn rank(&self) -> usize
pub fn rank(&self) -> usize
Effective rank of the design matrix (sklearn rank_, _base.py:505).
The rank of the matrix actually solved by linalg.lstsq — the
centered X when fit_intercept is true, the raw X otherwise
(_base.py:687).
Sourcepub fn singular_values(&self) -> &Array1<F>
pub fn singular_values(&self) -> &Array1<F>
Singular values of the design matrix (sklearn singular_,
_base.py:508).
The singular values of the matrix actually solved by linalg.lstsq
— the centered X when fit_intercept is true, the raw X
otherwise (_base.py:687).